@@ -52,8 +52,8 @@ def SetAlarm():
             txt=_('Stop')
             action_stop.label =str(txt.encode( "utf-8" ))
             action_stop.flags |= alarm.ACTION_WHEN_RESPONDED | alarm.ACTION_TYPE_NOP
-        else: #use own (external) alarm
-            print "* Use external alarm: "+data.AlternativeAlarm
+        else: #use own (alternative) alarm
+            print "* Use alternative alarm: "+data.AlternativeAlarm
             action_run = event.add_actions(1)[0]
             action_run.flags |= alarm.ACTION_WHEN_TRIGGERED | alarm.ACTION_TYPE_EXEC
             action_run.command = data.AlternativeAlarm
