@@ -221,6 +221,20 @@ def LoadConfig():
         config.set('main', 'WakeUp_Song_Duration', str(data.WakeUp_Song_Duration))
 
 
+    try:
+        data.AlternativeAlarm = config.get('main', 'AlternativeAlarm')
+    except:
+        config.set('main', 'AlternativeAlarm', str(data.AlternativeAlarm))
+
+    try:
+        tmp = config.get('main', 'UseAlternativeAlarm')
+        if(tmp=="True"): data.UseAlternativeAlarm=True
+        else: data.UseAlternativeAlarm=False
+    except:
+        config.set('main', 'UseAlternativeAlarm', str(data.UseAlternativeAlarm))
+
+
+
 ## Add forced configuration changes here
     try:
         configFileVersion = config.getint('main', 'configFileVersion')
@@ -492,4 +506,4 @@ def CloseMediaPlayer():
 #    t2=1000*(now-data.passed_time2)
 #    print "### ",  str(int(t)), "ms, (",  str(int(t2)), "ms delta): ", text
 #
-#    data.passed_time2 = time.time()
+#    data.passed_time2 = time.time()
\ No newline at end of file
